==> pollen-ui-struts2-1.3.1.1-sources.jar: org/chorem/pollen/ui/actions/user/DeletePollAccount.java <==
/*
 * #%L
 * Pollen :: UI (strust2)
 * 
 * $Id: DeletePollAccount.java 3394 2012-05-28 15:27:04Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.3.1.1/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/user/DeletePollAccount.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.user;

import com.google.common.base.Preconditions;
import org.chorem.pollen.business.persistence.PersonList;
import org.chorem.pollen.business.persistence.PollAccount;
import org.chorem.pollen.services.impl.FavoriteService;
import org.chorem.pollen.ui.actions.PollenActionSupport;

/**
 * Delete a selected favorite list for the connected user.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class DeletePollAccount extends PollenActionSupport {

    private static final long serialVersionUID = 1L;

    protected String favoriteListId;

    protected String pollAccountId;

    protected String redirectUrl;

    public void setRedirectUrl(String redirectUrl) {
        this.redirectUrl = redirectUrl;
    }

    public void setFavoriteListId(String favoriteListId) {
        this.favoriteListId = favoriteListId;
    }

    public void setPollAccountId(String pollAccountId) {
        this.pollAccountId = pollAccountId;
    }

    public String getRedirectUrl() {
        return redirectUrl;
    }

    public String execute() throws Exception {

        Preconditions.checkNotNull(pollAccountId);

        FavoriteService service = newService(FavoriteService.class);

        PersonList favoriteList = service.getEntityById(PersonList.class,
                                                        favoriteListId);

        PollAccount pollAccount = service.getEntityById(PollAccount.class,
                                                        pollAccountId);

        service.removePollAccountToFavoriteList(favoriteList, pollAccount);

        getTransaction().commitTransaction();

        addFlashMessage(
                _("pollen.information.pollAccount.removedFromFavoriteList",
                  pollAccount.getVotingId()));

        return SUCCESS;
    }
}

==> pollen-ui-struts2-1.4-sources.jar: org/chorem/pollen/ui/actions/user/DeletePollAccount.java <==
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: DeletePollAccount.java 3423 2012-06-05 16:50:22Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.4/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/user/DeletePollAccount.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.user;

import com.google.common.base.Preconditions;
import org.chorem.pollen.business.persistence.PersonList;
import org.chorem.pollen.business.persistence.PollAccount;
import org.chorem.pollen.services.impl.FavoriteService;
import org.chorem.pollen.ui.actions.PollenActionSupport;

/**
 * Delete a selected favorite list for the connected user.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class DeletePollAccount extends PollenActionSupport {

    private static final long serialVersionUID = 1L;

    protected String favoriteListId;

    protected String pollAccountId;

    protected String redirectUrl;

    public void setRedirectUrl(String redirectUrl) {
        this.redirectUrl = redirectUrl;
    }

    public void setFavoriteListId(String favoriteListId) {
        this.favoriteListId = favoriteListId;
    }

    public void setPollAccountId(String pollAccountId) {
        this.pollAccountId = pollAccountId;
    }

    public String getRedirectUrl() {
        return redirectUrl;
    }

    public String execute() throws Exception {

        Preconditions.checkNotNull(pollAccountId);

        FavoriteService service = getFavoriteService();

        PersonList favoriteList = service.getEntityById(PersonList.class,
                                                        favoriteListId);

        PollAccount pollAccount = service.getEntityById(PollAccount.class,
                                                        pollAccountId);

        service.removePollAccountToFavoriteList(favoriteList, pollAccount);

        addFlashMessage(
                _("pollen.information.pollAccount.removedFromFavoriteList",
                  pollAccount.getVotingId()));

        return SUCCESS;
    }
}
